
.. all-saltext.vmware.states:

-------------
State Modules
-------------

.. autosummary::
    :toctree:

    saltext.elasticsearch.states.__init__
    saltext.elasticsearch.states.elasticsearch_mod
